#
# spec file for package python-django-attachments
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python36 1
Name:           python-django-attachments
Version:        1.11
Release:        1.5
Summary:        Attach files to any Django model
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/bartTC/django-attachments
Source:         https://files.pythonhosted.org/packages/source/d/django-attachments/django-attachments-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-django >= 1.11
Requires:       python-six
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module django >= 1.11}
BuildRequires:  %{python_module pytest-django}
BuildRequires:  %{python_module six}
# /SECTION
%python_subpackages

%description
django-attachments is generic Django application to attach Files (Attachments) to any model.

%prep
%setup -q -n django-attachments-%{version}
sed -i '/mock/d;/-cov/d;/flakes/d' setup.cfg
sed -i 's/import mock/from unittest import mock/' attachments/tests/test_views.py

%build
%python_build

%install
%python_install
%{python_expand rm -r %{buildroot}%{$python_sitelib}/attachments/tests/
%fdupes %{buildroot}%{$python_sitelib}
}

%check
export DJANGO_SETTINGS_MODULE=attachments.tests.testapp.settings
PYTHONPATH=.
%pytest

%files %{python_files}
%doc CHANGELOG.rst README.rst
%license LICENSE
%{python_sitelib}/*

%changelog
* Sun Apr 23 2023 Dirk Müller <dmueller@suse.com>
- update to 1.11:
  * Return form errors as JSON from ``add_attachment()`` view
    when the ``X-Return-Form-Errors`` request header is present.
    Response code is 400 - BAD REQUEST because this is a client
    error.
* Sun Apr 16 2023 Dirk Müller <dmueller@suse.com>
- update to 1.10:
  * Support custom form validators via
    ``AppConfig.attachment_validators``
  * Remove quotes from "attachment_list" (Aaron C. de Bruyn)
  * Add a URL for matching objects with a UUID4 primary key. Fix
  * `Issue #94 <https://github.com/bartTC/django-
    attachments/issues/94>`_
  * Document settings supported by django-attachments
  * Document how to make a new release. Closes
  * Add testing with Django 4.0 and 4.1, Python 3.9 and 3.10
    and switch the default Python version used to 3.10
  * Add testing w/ Python 3.11 - supported only on Django 4.1 for
    now
* Tue Apr 19 2022 Markéta Machová <mmachova@suse.com>
- Update to 1.9.1
  * Configure PK explicitly to AutoField for Django 3.2+
- do not use mock
* Fri Jan  7 2022 John Vandenberg <jayvdb@gmail.com>
- Skip Tumbleweed Python 3.6 incompatible with Django 4
* Tue Apr  6 2021 Markéta Machová <mmachova@suse.com>
- Normalize pytest settings
* Mon Sep  7 2020 John Vandenberg <jayvdb@gmail.com>
- Activate test suite
- Update to v1.8
* Sun May  3 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v1.5
* Thu Aug 13 2009 alexandre@exatati.com.br
- Initial package (0.3.1) for openSUSE.
